@@ -25,4 +25,4 @@ except IOError:
 
 config['trello']['work_board_id'] = '1KsoiV9e'
 config['trello']['work_column_name'] = 'Doing'
-config['trello']['pause_column_name'] = 'Paused/Waiting'
+config['trello']['pause_column_name'] = 'Ready'
