@@ -4,9 +4,9 @@ from paver.setuputils import setup
 options = environment.options
 
 NAME = 'blackbelt'
-VERSION = '0.7.5'
+VERSION = '0.9.1'
 
-requires = ['click', 'requests', 'trello', 'PyGithub']
+requires = ['click', 'requests', 'PyGithub']
 
 setup(
     name=NAME,
